# DalitzFit
The DalitzFit example provides (hopefully) an easy starting point for the work with ComPWA. Basically we construct all the objects that are needed for the analysis, generate a data sample according to a given amplitude model and fit the model to the sample. In the end the fit result is printed and data sample as well as amplitude are plotted. 
